@@ -9,6 +9,11 @@ class ClientError(Exception):
             self.message = str(args.pop(0))
         for key in list(kwargs.keys()):
             setattr(self, key, kwargs.pop(key))
+        if not self.message:
+            self.message = "{title} ({body})".format(
+                title=getattr(self, 'reason', 'Unknown'),
+                body=getattr(self, 'error_type', vars(self))
+            )
         super().__init__(self.message, *args, **kwargs)
         if self.response:
             self.code = self.response.status_code
