@@ -99,16 +99,17 @@ class PrivateRequestMixin:
     @property
     def base_headers(self):
         locale = self.locale.replace("-", "_")
+        # next_year = time.time() + 31536000  # + 1 year in seconds
         return {
             "X-IG-App-Locale": locale,
             "X-IG-Device-Locale": locale,
             "X-IG-Mapped-Locale": locale,
-            "X-Pigeon-Session-Id": self.generate_uuid(),
-            "X-Pigeon-Rawclienttime": str(round(time.time() * 1000) / 1000),
-            "X-IG-Connection-Speed": "-1kbps",
-            "X-IG-Bandwidth-Speed-KBPS": "-1.000",  # str(random.randint(2900000, 10000000) / 1000),
-            "X-IG-Bandwidth-TotalBytes-B": "0",  # str(random.randint(5000000, 90000000)),
-            "X-IG-Bandwidth-TotalTime-MS": "0",  # str(random.randint(5000, 15000)),
+            "X-Pigeon-Session-Id": self.generate_uuid('UFS-', '-1'),
+            "X-Pigeon-Rawclienttime": str(round(time.time(), 3)),
+            # "X-IG-Connection-Speed": "-1kbps",
+            "X-IG-Bandwidth-Speed-KBPS": str(random.randint(2500000, 3000000) / 1000),  # "-1.000"
+            "X-IG-Bandwidth-TotalBytes-B": str(random.randint(5000000, 90000000)),  # "0"
+            "X-IG-Bandwidth-TotalTime-MS": str(random.randint(2000, 9000)),  # "0"
             # "X-IG-EU-DC-ENABLED": "true", # <- type of DC? Eu is euro, but we use US
             # "X-IG-Prefetch-Request": "foreground",  # OLD from instabot
             "X-IG-App-Startup-Country": self.country.upper(),
@@ -116,25 +117,36 @@ class PrivateRequestMixin:
                 json.dumps(self.device_settings).encode()
             ).hexdigest(),
             "X-IG-WWW-Claim": "0",
+            # X-IG-WWW-Claim: hmac.AR3zruvyGTlwHvVd2ACpGCWLluOppXX4NAVDV-iYslo9CaDd
             "X-Bloks-Is-Layout-RTL": "false",
-            # "X-Bloks-Enable-RenderCore": "false",  # OLD from instabot
-            "X-MID": self.mid,  # "XkAyKQABAAHizpYQvHzNeBo4E9nm" in instabot
             "X-Bloks-Is-Panorama-Enabled": "true",
             "X-IG-Device-ID": self.uuid,
+            "X-IG-Family-Device-ID": self.phone_id,
             "X-IG-Android-ID": self.device_id,
+            "X-IG-Timezone-Offset": self.timezone_offset,
             "X-IG-Connection-Type": "WIFI",
-            "X-IG-Capabilities": "3brTvwM=",  # "3brTvwE=" in instabot
+            "X-IG-Capabilities": "3brTvx0=",  # "3brTvwE=" in instabot
             "X-IG-App-ID": "567067343352427",
+            "Priority": "u=3",
             "User-Agent": self.user_agent,
             "Accept-Language": locale.replace("_", "-"),
-            "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",
-            "Accept-Encoding": "gzip, deflate",
+            "X-MID": self.mid,  # e.g. X--ijgABABFjLLQ1NTEe0A6JSN7o
+            "IG-INTENDED-USER-ID": str(self.user_id or 0),
+            "IG-U-DS-USER-ID": str(self.user_id or 0),
+            "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",  # default for post
+            "Accept-Encoding": "gzip, deflate",  # ignore zstd
             # "Host": "i.instagram.com",
             "X-FB-HTTP-Engine": "Liger",
-            "Connection": "keep-alive",  # "close" in instabot
+            "Connection": "keep-alive",
             # "Pragma": "no-cache",
             # "Cache-Control": "no-cache",
             "X-FB-Client-IP": "True",
+            "X-FB-Server-Cluster": "True",
+            # Direct:
+            # IG-U-IG-DIRECT-REGION-HINT: LLA,{self.user_id},{next_year}:01f7bae7d8b131877d8e0ae1493252280d72f6d0d554447cb1dc9049b6b2c507c08605b7
+            # IG-U-SHBID: 12695,{self.user_id},{next_year}:01f778d9c9f7546cf3722578fbf9b85143cd6e5132723e5c93f40f55ca0459c8ef8a0d9f
+            # IG-U-SHBTS: {int(time.time())},{self.user_id},{next_year}:01f7ace11925d0388080078d0282b75b8059844855da27e23c90a362270fddfb3fae7e28
+            # IG-U-RUR: CLN,{self.user_id},{next_year}:01f7f627f9ae4ce2874b2e04463efdb184340968b1b006fa88cb4cc69a942a04201e544c
         }
 
     def set_country(self, country: str = "US"):
@@ -168,7 +180,27 @@ class PrivateRequestMixin:
         bool
             A boolean value
         """
+        user_agent = (self.settings.get("user_agent") or "").replace(self.locale, locale)
         self.locale = locale
+        self.set_user_agent(user_agent)  # update locale in user_agent
+        if '_' in locale:
+            self.set_country(locale.rsplit('_', 1)[1])
+        return True
+
+    def set_timezone_offset(self, seconds: int = 0):
+        """Set you timezone offset in seconds
+
+        Parameters
+        ----------
+        seconds: int
+            Specify the offset in seconds from UTC
+
+        Returns
+        -------
+        bool
+            A boolean value
+        """
+        self.timezone_offset = seconds
         return True
 
     @staticmethod
